/*
 * $Id$
 *
 * Definitions for mondorestore
 */

/**
 * Compatibility #define to ease the transition to logfile-in-a-variable.
 */
char *MONDO_LOGFILE = "/tmp/mondorestore.log";

/* Busybox ps has no option and PID in first pos */
char *ps_options = "";
char *ps_proc_id = "$1";
